m4-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Changes to m4/m4/m4.c,v


From: Eric Blake
Subject: Changes to m4/m4/m4.c,v
Date: Fri, 06 Oct 2006 13:13:15 +0000

CVSROOT:        /sources/m4
Module name:    m4
Changes by:     Eric Blake <ericb>      06/10/06 13:13:15

Index: m4/m4.c
===================================================================
RCS file: /sources/m4/m4/m4/m4.c,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -b -r1.20 -r1.21
--- m4/m4.c     5 Oct 2006 23:07:28 -0000       1.20
+++ m4/m4.c     6 Oct 2006 13:13:15 -0000       1.21
@@ -53,8 +53,9 @@
   if (context->syntax)
     m4_syntax_delete (context->syntax);
 
-  /* debug_file should have been reset to stderr, which is closed later.  */
-  assert (context->debug_file == stderr);
+  /* debug_file should have been reset to stdout or stderr, both of
+     which are closed later.  */
+  assert (context->debug_file == stderr || context->debug_file == stdout);
 
   obstack_free (&context->trace_messages, NULL);
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]